\name{count}
\alias{count}
\alias{count.default}
\alias{count.wprof}

\title{
OPHI counting approach
}
\description{
The function implements in a single call the computations involved in OPHI
counting approach. The OPHI approach can be applied also when cardinal variables
are of concern. The function implements the methodology for ordinal variables
only.
}
\usage{
count(y, ...)
\method{count}{default}(y, z, w=rep(1, ncol(y)), k=sum(w), freq=rep(1, nrow(y)), ...)
\method{count}{wprof}(y, ...)
}

\arguments{
  \item{y}{
matrix of profiles, it can be substituted by an object of class \code{wprof}.
}
  \item{z}{
vector of cutoffs.
}
  \item{w}{
variables weights.
}
  \item{k}{
overall cutoff.
}
  \item{freq}{
profiles frequencies, if \code{y} is an object of class \code{wprof} this
argument can be omitted.
}
  \item{\dots}{
any of the above.
}
}
\value{
An object of S3 class \code{ophi} that contains all the informations and
evaluations related to the OPHI counting approach. The object is a \code{list}
of the following arguments
\item{y}{
the matrix of profiles,
}
\item{freq}{
the profiles frequencies,
}
\item{d}{
the variables number,
}
\item{n}{
the observations number (frequencies sum),
}
\item{z}{
vector of cutoffs,
}
\item{k}{
overall cutoff,
}
\item{rho}{
the function used to compare the profiles with the vector of cutoffs,
}
\item{rho_k}{
the function used to compare the profiles with the overall cutoff by weighting
the variables,
}
\item{g0}{
a matrix profiles-variables reporting the results of the function
\code{rho},
}
\item{c}{
the censored vector of deprivation counts,
}
\item{Z_k}{
a boolean vector that for each profile indicate if it identifies a state of
deprivation,
}
\item{q}{
the number of poor in the population of \code{n} units,
}
\item{H}{
the headcount ratio,
}
\item{A}{
the average deprivation share ,
}
\item{M0}{
the adjusted headcount ratio.
}
}
\references{
Alkire S., Foster J. (2011), Counting and multidimensional poverty measurement, Journal of Public Economics, 96(7-8), 476-487.
}
\examples{
vl <- c(2, 3, 3, 2)
prof <- var2prof(varlen = vl)

res <- count(prof, z = c(1, 2, 1, 1), k = 1)

res
}