\name{count2threshold}
\alias{count2threshold}

\title{
Poset threshold from the OPHI counting approach
}
\description{
The function defines the threshold for the poset with profiles \code{prof} and
incidence matrix \code{zeta} from the OPHI counting approach described in the
argument \code{mpi}.
}
\usage{
count2threshold(mpi, prof, zeta = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mpi}{
an object of class \code{ophi}, see \code{\link{count}} for details.
}
  \item{prof}{
an object of class \code{wprof}.
}
  \item{zeta}{
an object of class \code{incidence}. The function can obtain the the complete
incidence matrix form the argument \code{prof}.
}
}

\seealso{
\code{\link{count}}
}
\examples{
vl <- c(2, 3, 3, 2)
prof <- var2prof(varlen = vl, labtype = "progressive")

res <- count(prof, z = c(1, 2, 1, 1), k = 1)

thr <- count2threshold(res, prof)

plot(prof, col = 1 + thr, lwd = 1 + res$c,
     main = "Comparison between OPHI and parsec",
     sub = "bold: deprived profiles identified by OPHI, red: parsec threshold")

eval <- evaluation(prof, thr, maxint = 10^4, nit = 10^7)

ord <- order(eval$identification_function, res$c)
plot(eval$identification_function[ord], col = "red", lwd=2, type = "l", xlab="",
     ylab = "", axes = FALSE, frame.plot = TRUE,
     main = "Comparison between OPHI and parsec",
     sub = "red: identification function, black: OPHI deprived profiles")
points(res$c[ord], type="l", lwd=2)
axis(2)
}